@@ -1,7 +1,7 @@
 # display a pie chart at an arbitrary location on an existing plot
 
-floating.pie<-function (xpos,ypos,x,edges=200,radius=1,col=NULL,
- startpos=0,...) {
+floating.pie<-function(xpos,ypos,x,edges=200,radius=1,col=NULL,
+ startpos=0,shadow=FALSE,...) {
  if (!is.numeric(x) || any(is.na(x) | x<=0))
   stop("floating.pie: x values must be positive.")
  x<-c(0,cumsum(x)/sum(x))
@@ -15,6 +15,11 @@ floating.pie<-function (xpos,ypos,x,edges=200,radius=1,col=NULL,
  yradius<-radius*(xylim[4]-xylim[3])/(xylim[2]-xylim[1])*plotdim[1]/plotdim[2]
  # get the center values in radians
  bc<-2*pi*(x[1:nx]+dx/2)+startpos
+ if(shadow) {
+  xc<-c(cos(seq(0,2*pi,length=edges))*radius+xpos)
+  yc<-c(sin(seq(0,2*pi,length=edges))*yradius+ypos)
+  polygon.shadow(xc,yc)
+ }
  for(i in 1:nx) {
   n<-max(2,floor(edges*dx[i]))
   t2p<-2*pi*seq(x[i],x[i + 1],length=n)+startpos
@@ -24,7 +29,6 @@ floating.pie<-function (xpos,ypos,x,edges=200,radius=1,col=NULL,
   t2p<-2*pi*mean(x[i+0:1])+startpos
   xc<-cos(t2p)*radius
   yc<-sin(t2p)*radius
-  lines(c(1,1.05)*xc,c(1,1.05)*yc)
  }
  return(bc)
 }
@@ -35,6 +39,8 @@ floating.pie<-function (xpos,ypos,x,edges=200,radius=1,col=NULL,
 pie.labels<-function(x,y,angles,labels,radius=1,bg="white",border=TRUE,...) {
  if(nargs()<4)
   stop("Usage: pie.labels(x,y,angles,labels,radius=1,bg=\"white\",border=TRUE,...)")
+ # turn off clipping
+ par(xpd=TRUE)
  # scale the y radius
  xylim<-par("usr")
  plotdim<-par("pin")
@@ -42,4 +48,6 @@ pie.labels<-function(x,y,angles,labels,radius=1,bg="white",border=TRUE,...) {
  xc<-cos(angles)*radius+x
  yc<-sin(angles)*yradius+y
  boxed.labels(xc,yc,labels,bg=bg,border=border,...)
+ # turn clipping back on
+ par(xpd=FALSE)
 }
